# -*- coding: utf-8 -*-

# Resource object code
#
# Created: Sat Jun 23 08:27:12 2012
#      by: The Resource Compiler for PySide (Qt v4.8.0)
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore

qt_resource_data = "\x00\x00\x04~\x00\x00\x01\x00\x01\x00\x10\x10\x00\x00\x00\x00\x00\x00h\x04\x00\x00\x16\x00\x00\x00(\x00\x00\x00\x10\x00\x00\x00 \x00\x00\x00\x01\x00 \x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00 \x00\x00\x00B\x00\x00\x00A\x00\x00\x00A\x00\x00\x00A\x00\x00\x00A\x00\x00\x00A\x00\x00\x00A\x00\x00\x00A\x00\x00\x00A\x00\x00\x00A\x00\x00\x00?\x00\x00\x00\x12\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x006\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe5\xea\xe7\xffzzz\x9e\x00\x00\x00\x13\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x006\xfb\xfb\xfb\xff\xf8\xf8\xf8\xff\xbf\xbf\xbf\xff\xfb\xfb\xfb\xff\xbf\xbf\xbf\xff\xfb\xfb\xfb\xff\xbf\xbf\xbf\xff\xfb\xfb\xfb\xff\xb4\xb4\xb4\xff\xf7\xff\xfd\xff\xcd;\x84\xfe\xff\xff\xff\xff\x7f\x7f\x7f\x99\x00\x00\x00\x0c\x00\x00\x00\x00\x00\x00\x006\xfc\xfc\xfc\xff\xf7\xf7\xf7\xff\xfd\xfd\xfd\xff\xf6\xf6\xf6\xff\xfd\xfd\xfd\xff\xf6\xf6\xf6\xff\xfd\xfd\xfd\xff\xf6\xf6\xf6\xff\xfd\xfd\xfd\xff\xf6\xf6\xf6\xff\xe5\xf3\xed\xff\xc3\xc3\xc2\xfe\xe8\xe8\xe8\xff\x00\x00\x00<\x00\x00\x00\x00\x00\x00\x006\xfc\xfc\xfc\xff\xfa\xfa\xfa\xff\xbf\xbf\xbf\xff\xfe\xfe\xfe\xff\xbf\xbf\xbf\xff\xfe\xfe\xfe\xff\xbf\xbf\xbf\xff\xff\xff\xff\xff\xb4\xb4\xb4\xff\xf9\xff\xff\xff\xffO\xa8\xff\xf6\xff\xfc\xff\xff\xff\xff\xff\x00\x00\x00?\x00\x00\x00\x00\x00\x00\x006\xfd\xfd\xfd\xff\xf9\xf9\xf9\xff\xff\xff\xff\xff\xf8\xf8\xf8\xff\xff\xff\xff\xff\xf8\xf8\xf8\xff\xff\xff\xff\xff\xf8\xf8\xf8\xff\xff\xff\xff\xff\xf7\xf8\xf8\xff\xf7\xff\xff\xff\xf8\xf8\xf7\xff\xff\xff\xff\xff\x00\x00\x00?\x00\x00\x00\x00\x00\x00\x006\xfe\xfe\xfe\xff\xfd\xfd\xfd\xff\xbe\xbe\xbe\xff\xff\xff\xff\xff\xbe\xbe\xbe\xff\xff\xff\xff\xff\xbe\xbe\xbe\xff\xff\xff\xff\xff\xb3\xb3\xb3\xff\xfc\xff\xff\xff\xffN\xa8\xff\xf8\xff\xfd\xff\xff\xff\xff\xff\x00\x00\x00?\x00\x00\x00\x00\x00\x00\x006\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xff\xff\xf9\xfa\xfa\xff\xf9\xff\xff\xff\xfa\xfa\xf9\xff\xff\xff\xff\xff\x00\x00\x00?\x00\x00\x00\x00\x00\x00\x006\xff\xff\xff\xff\xfe\xfe\xfe\xff\xbd\xbd\xbd\xff\xff\xff\xff\xff\xbd\xbd\xbd\xff\xff\xff\xff\xff\xbd\xbd\xbd\xff\xff\xff\xff\xff\xb3\xb3\xb3\xff\xfe\xff\xff\xff\xffM\xa6\xff\xfa\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00?\x00\x00\x00\x00\x00\x00\x004\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00=\x00\x00\x00\x00\x003\x00\xa8\x13\x9a\x16\xff\x00\x80\x00\xff\x00\x8a\x00\xff\x00\x91\x05\xff\x02\x99\x12\xff\x08\x9e\x1c\xff\x0a\xa1\x1f\xff\x07\x9f\x1c\xff\x00\x95\x08\xff\x00\x8f\x00\xff\x00\x85\x00\xff\x00\x80\x00\xff\x14\x9c\x19\xff\x0aE\x09\xa5\x00\x00\x00\x00\x001\x00\xa2(\xa6,\xff\x00\x8d\x01\xff\x09\x96\x10\xff\x11\x9f!\xff\x19\xa90\xff \xb1>\xff#\xb5D\xff\x1d\xb1=\xff\xd1\xef\xd6\xff\x89\xd0\x91\xff\xcd\xe9\xce\xffU\xb3W\xff(\xa7-\xff\x0aC\x0a\x9f\x00\x00\x00\x00\x000\x00\xa2(\xa7,\xff\x01\x92\x04\xff\x0a\x9c\x17\xff\x15\xa9*\xff\x1b\xae9\xff'\xbbN\xff-\xc4Z\xff'\xbcO\xff\x13\xad3\xff\x0e\xa7$\xff\x00\x9a\x0e\xff\x00\x91\x00\xff(\xa8-\xff\x0aB\x0a\x9f\x00\x00\x00\x00\x000\x00\xa3N\xc2V\xff\x80\x9b\x7f\xfe{\x9cz\xff\x7f\x9b}\xfe\x84\xe7\x9b\xff\x97\xef\xb1\xff\xa2\xf8\xbf\xff\x9a\xf2\xb5\xff\x8b\xe9\xa1\xff{\x97w\xfe{\x9cz\xff\x82\x9c\x80\xfeI\xc4S\xff\x06@\x06\xa0\x00\x00\x00\x00\x00>\x00_\x00,\x00\xae\xff\xfa\xff\xff\xf4\xf3\xf4\xff\xf9\xf6\xf8\xff\x00\x19\x00\xa9\x00+\x00\xad\x00*\x00\xad\x00+\x00\xad\x00\x1b\x00\xa9\xff\xfd\xff\xff\xf4\xf3\xf4\xff\xff\xfc\xff\xff\x00\x1c\x00\xa9\x00=\x00\x5c\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\x00\x99\x99\x99\xff\x99\x99\x99\xff\x9a\x9a\x9a\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x99\x99\x99\xff\x99\x99\x99\xff\x99\x99\x99\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\xff\xff\x00\x00\x80\x07\x00\x00\x80\x03\x00\x00\x80\x03\x00\x00\x80\x03\x00\x00\x80\x03\x00\x00\x80\x03\x00\x00\x80\x03\x00\x00\x80\x03\x00\x00\x80\x03\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x80\x03\x00\x00\xc7\xc7\x00\x00\x00\x00\x04~\x00\x00\x01\x00\x01\x00\x10\x10\x00\x00\x00\x00\x00\x00h\x04\x00\x00\x16\x00\x00\x00(\x00\x00\x00\x10\x00\x00\x00 \x00\x00\x00\x01\x00 \x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00\x01\x00\x00\x00\x14\x00\x00\x00\x01\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00\x01\x00\x00\x00\x14\x00\x00\x00\x01\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00\x08\x00\x00\x00\x98\x11\x11\x11\xf3124\xff\x0b\x0b\x0b\xf4\x00\x00\x00\x9d\x00\x00\x00\x0a\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00\x0a\x00\x00\x00\x9d\x0b\x0b\x0b\xf4124\xff\x10\x10\x10\xf3\x00\x00\x00\x98\x00\x00\x00\x08\x00\x00\x00\x8e#%&\xffFWi\xffTr\x95\xffz\x91\xab\xff@BE\xff\x00\x00\x00\x93\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00\x93@BE\xffz\x91\xab\xffTr\x95\xffFWi\xff#%&\xff\x00\x00\x00\x8e\x00\x00\x00\xed\x1f(6\xff\x00!H\xff\x0bC\x86\xff\x0bI\x90\xffRbv\xff\x0e\x0e\x0e\xf6\x00\x00\x00\x13\x00\x00\x00\x13\x0e\x0e\x0e\xf6Rbv\xff\x0bI\x90\xff\x07@\x84\xff\x09)N\xff\x1e(6\xff\x00\x00\x00\xed\x0a\x0a\x0a\xec(0<\xff\x1c3S\xff=a\x90\xff;[\x87\xffMXh\xff\x17\x17\x17\xff\x01\x01\x01\xcf\x01\x01\x01\xcf\x17\x17\x17\xffMXh\xff4W\x84\xff?b\x91\xff\x1c3S\xff%,9\xff\x04\x04\x04\xeb\x00\x00\x00\xbeRSU\xff$*6\xff\x1f(8\xff=HY\xffopr\xff\x1c\x1c\x1c\xff(((\xff(((\xff\x1b\x1b\x1b\xffopr\xff=HY\xff\x1f(8\xff$*6\xffRSU\xff\x00\x00\x00\xbe\x00\x00\x00G\x15\x15\x15\xffhhh\xff}~\x81\xffxxx\xff###\xff'''\xff\x18\x18\x18\xff\x18\x18\x18\xff'''\xff###\xffxxx\xff}~\x81\xffhhh\xff\x15\x15\x15\xff\x00\x00\x00G\xff\xff\xff\x00\x00\x00\x00\xa5666\xffMMM\xffiii\xff222\xffNNN\xff\x13\x13\x13\xff\x01\x01\x01\xffMMM\xff222\xffiii\xffMMM\xff666\xff\x00\x00\x00\xa5\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00$\x1b\x1b\x1b\xfbsss\xff+++\xffJJJ\xff\x17\x17\x17\xffiii\xffVVV\xff\x17\x17\x17\xffJJJ\xff+++\xffsss\xff\x1b\x1b\x1b\xfb\x00\x00\x00$\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00G\x00\x00\x00\xd1,,,\xff---\xff\x16\x16\x16\xff\x12\x12\x12\xf6\x12\x12\x12\xf6\x16\x16\x16\xff+++\xff,,,\xff\x00\x00\x00\xd1\x00\x00\x00G\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00\x19\x1f\x1f\x1f\xfcjjj\xff$$$\xff\x00\x00\x00)\x00\x00\x00&$$$\xffjjj\xff\x1f\x1f\x1f\xfc\x00\x00\x00\x19\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00b\x00\x00\x00\xcc\x00\x00\x00\x81\xff\xff\xff\x00\xff\xff\xff\x00\x00\x00\x00\x81\x00\x00\x00\xcc\x00\x00\x00b\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\x00\x00\xff\xff\x00\x00\xff\xff\x00\x00\x83\xc1\x00\x00\x01\x80\x00\x00\x01\x80\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x01\x00\x00\x80\x01\x00\x00\xc0\x03\x00\x00\xe0\x07\x00\x00\xf1\x8f\x00\x00\xf9\x9f\x00\x00\xff\xff\x00\x00\xff\xff\x00\x00"
qt_resource_name = "\x00\x09\x08)\x1d\x09\x00q\x00t\x00a\x00l\x00c\x00h\x00e\x00m\x00y\x00\x07\x0d\xfa\xdcS\x00w\x00i\x00d\x00g\x00e\x00t\x00s\x00\x11\x0cf\xe5\x9f\x00v\x00i\x00e\x00w\x00-\x00c\x00a\x00l\x00e\x00n\x00d\x00a\x00r\x00.\x00i\x00c\x00o\x00\x0f\x07\xefy\xdf\x00e\x00d\x00i\x00t\x00-\x00f\x00i\x00n\x00d\x00-\x006\x00.\x00i\x00c\x00o"
qt_resource_struct = "\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x02\x00\x00\x00\x18\x00\x02\x00\x00\x00\x02\x00\x00\x00\x03\x00\x00\x00T\x00\x00\x00\x00\x00\x01\x00\x00\x04\x82\x00\x00\x00,\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00"
def qInitResources():
    QtCore.qRegisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()



# -*- coding: utf-8 -*-
##############################################################################
#       Copyright (C) 2012, Joel B. Mohler <joel@kiwistrawberry.us>
#
#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
#                  http://www.gnu.org/licenses/
##############################################################################

from qtalchemy import *
import decimal
import datetime

def ReportLabSize(str_pagesize):
    """
    Accepts input of a string "encoded" pagesize and translates it to a reportlab pagesize value.
    
    Example:
    >>> ReportLabSize("letter")
    (612.0, 792.0)
    >>> ReportLabSize("legal")
    (612.0, 1008.0)
    >>> # a4 page dimensions are not rounded the same on diverse platforms
    >>> tuple(AttrNumeric(2)(x) for x in ReportLabSize("landscape_a4"))
    (Decimal('841.89'), Decimal('595.28'))
    >>> ReportLabSize("landscape_letter")
    (792.0, 612.0)
    >>> ReportLabSize("portrait_letter")==ReportLabSize("letter")
    True
    """
    from reportlab.lib import pagesizes

    if str_pagesize is None:
        mod, size = "", "letter" # sorry, I'm very North American
    elif '_' in str_pagesize:
        mod, size = str_pagesize.split('_',2)
    else:
        mod, size = "", str_pagesize
    if not size.upper() in ("LETTER","LEGAL","ELEVENSEVENTEEN") + tuple("A{0}".format(i) for i in range(7)) + tuple("B{0}".format(i) for i in range(7)):
        raise ValueError( "the pagesize {0} is not valid".format(size) )
    if not mod.lower() in ("landscape","portrait",""):
        raise ValueError( "the pagesize modifier {0} is not valid".format(mod) )

    mySize = getattr(pagesizes,size.upper())
    if mod != "":
        mySize = getattr(pagesizes,mod.lower())(mySize)
    return mySize

def SuppressedZero(attr):
    def format(x):
        if x == 0:
            return ""
        else:
            return AttrNumeric(2)(x)

    return lambda instance: format(getextendedattr(instance, attr))
sz = SuppressedZero

class Numeric:
    def __init__(self, type_):
        self.type_ = type_

    def __call__(self, attr):
        def format(x):
            return str(self.type_(x))
        return lambda instance: format(getextendedattr(instance, attr))

def safe_none(v):
    """
    >>> safe_none(None)
    ''
    >>> safe_none("1234")
    '1234'
    """
    if v is None:
        v = ""
    elif isinstance(v, str):
        v = v.replace("&", "&amp;")
    return v

def u(attr):
    return lambda instance: safe_none(getextendedattr(instance, attr))

def FormattedDate(attr):
    return lambda instance: getextendedattr(instance, attr).strftime("%x")
fd = FormattedDate

def ColumnWidthRatios(cols, pageSize, marginLeft, marginRight):
    """
    Internal width computations for GeraldoElements and GeraldoHeaders.

    >>> from geraldo.utils import inch
    >>> quantize = lambda x: str(AttrNumeric(2)(x))
    >>> cols = [ModelColumn("name", str, width=15),
    ...         ModelColumn("description", str, width=35)]
    >>> ColumnWidthRatios(cols, pageSize=None, marginLeft=.5*inch, marginRight=0)
    [140.4, 327.6]
    """
    from geraldo.utils import inch
    
    if pageSize is None:
        pageSize = "LETTER" # north american bias
    pageSize = ReportLabSize(pageSize)

    detailRatios = [m.width for m in cols]
    if set(detailRatios) == set([None]):
        detailRatios = None

    # where does the 1.5 inch come from
    totalMargins = marginLeft + marginRight + 1.5*inch

    if detailRatios is None:
        detailRatios = [(pageSize[0] - totalMargins) / len(cols)] * len(cols)
    else:
        widths = sum(detailRatios)
        for i in range(len(cols)):
            detailRatios[i] = detailRatios[i] * (pageSize[0] - totalMargins) / widths

    return detailRatios

def GeraldoElements(cols, pageSize=None, marginLeft=0, marginRight=0):
    """
    Return a list of geraldo elements converted from a list of ModelColumn objects.
    
    :param cols:  list of ModelColumn objects
    :param pageSize:  a string page size name.  See :func:`ReportLabSize`
    :param marginLeft:  padding for empty space to the left
    :param marginRight:  padding for empty space to the right
    
    >>> from geraldo.utils import cm, inch
    >>> quantize = lambda x: str(AttrNumeric(2)(x))
    >>> cols = [ModelColumn("name", str, width=15),
    ...         ModelColumn("description", str, width=35)]
    >>> elts = GeraldoElements(cols)
    >>> [quantize(o.width) for o in elts]
    ['151.20', '352.80']
    >>> [quantize(o.left) for o in elts]
    ['0.00', '151.20']
    
    >>> elts = GeraldoElements(cols, marginLeft=2*cm)
    >>> [quantize(o.width) for o in elts]
    ['134.19', '313.12']
    >>> [quantize(o.left) for o in elts]
    ['56.69', '190.89']
    """
    from geraldo import ObjectValue, SystemField
    from geraldo.utils import inch
    from reportlab.lib.enums import TA_CENTER, TA_RIGHT, TA_LEFT

    detailRatios = ColumnWidthRatios(cols, pageSize, marginLeft, marginRight)

    det_elements = []
    for i in range(len(cols)):
        wf = u
        style = {}
        padRight = 0
        if cols[i].type_ is decimal.Decimal:
            style['alignment'] = TA_RIGHT
            #wf = sz
            padRight = .1*inch
        elif isinstance(cols[i].type_, AttrNumeric):
            style['alignment'] = TA_RIGHT
            wf = Numeric(cols[i].type_)
            padRight = .1*inch
        elif cols[i].type_ is datetime.date:
            wf = fd
        else:
            style['wordWrap'] = True
        
        det_elements.append(ObjectValue(
                    attribute_name=cols[i].attr, 
                    get_value=wf(cols[i].attr), 
                    top=0, 
                    left=marginLeft + sum([detailRatios[j] for j in range(i)]), 
                    width=detailRatios[i] - padRight, 
                    style=style))

    return det_elements


def GeraldoHeaders(cols, pageSize=None, marginLeft=0, marginRight=0):
    """
    Return a list of geraldo elements converted from a list of ModelColumn objects.
    
    :param cols:  list of ModelColumn objects
    :param pageSize:  a string page size name.  See :func:`ReportLabSize`
    :param marginLeft:  padding for empty space to the left
    :param marginRight:  padding for empty space to the right
    
    >>> from geraldo.utils import cm, inch
    >>> quantize = lambda x: str(AttrNumeric(2)(x))
    >>> cols = [ModelColumn("name", str, width=15),
    ...         ModelColumn("description", str, width=35)]
    >>> elts = GeraldoHeaders(cols)
    >>> [quantize(o.width) for o in elts]
    ['151.20', '352.80']
    >>> [quantize(o.left) for o in elts]
    ['0.00', '151.20']
    
    >>> elts = GeraldoHeaders(cols, marginLeft=2*cm)
    >>> [quantize(o.width) for o in elts]
    ['134.19', '313.12']
    >>> [quantize(o.left) for o in elts]
    ['56.69', '190.89']
    """
    from geraldo import ObjectValue, SystemField

    detailRatios = ColumnWidthRatios(cols, pageSize, marginLeft, marginRight)

    det_elements = []
    for i in range(len(cols)):
        det_elements.append(SystemField(
                    expression=cols[i].label,
                    top=0, 
                    left=marginLeft + sum([detailRatios[j] for j in range(i)]), 
                    width=detailRatios[i]))

    return det_elements




# -*- coding: utf-8 -*-

# Resource object code
#
# Created: Sat Jun 23 08:27:12 2012
#      by: The Resource Compiler for PySide (Qt v4.8.0)
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore

qt_resource_data = "\x00\x00\x047\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04gAMA\x00\x00\xaf\xc87\x05\x8a\xe9\x00\x00\x00\x06bKGD\x00\x00\x00\x00\x00\x00\xf9C\xbb\x7f\x00\x00\x00\x09pHYs\x00\x00\x00H\x00\x00\x00H\x00F\xc9k>\x00\x00\x00\x09vpAg\x00\x00\x00\x10\x00\x00\x00\x10\x00\x5c\xc6\xad\xc3\x00\x00\x01\xf5IDAT8\xcb\xa5\x93\xcdKTQ\x18\xc6\x7fg\xee\xd5\xa6.}\x11\xa5!5j\xb4\x9a6\xc6\xec\x9aED\x10\x04-j!C\xeb\xb00\x06\xb1MA\x11B\x11\xb4I\x14D\xaa\xbf\xc0\x08\x17\x03m\xacE\xf4\x01\xd1b\x8a6S\x8bP\xc3\x19\x94@%\xc7;\xd5\x9d\xf7}[\xdcI\x1c(Rz\xd6\xcf\xf9=\xe7y\x0e\xc7\x99\x19\xff#wvp\xe2r\xf6x\xe6\xeebh\x81\x19\xa0\x8a\xa9\x22*\x98\x1aj\x8a\x89\xa0f\x98\x08\xa2\xca\x8e\xd6h\xb5T*_\x9d\xbc\xd7;\xe6g\x8eeF[\x92A\xa2-\xb9\xa9\xe0`5\x94Q`\xcc\x0f#K\x84\x8b\xd5M_\xbd\x16Y\x02\xc071n\x9c\xeb\xd84 ?2K\x0c0\xc5\xcc\x88\xa740\xc09\xde\x15\x8b\x7f=|\xb4\xa7\x07Q\x89\x01\x98!\x22\xf4\x8d\xcc\xac\x19\x1e\x0et\x02\x90\xcdf\xff\x08\xa8V\xabh\xbd\x01\x10\x8d\x17\xbe\x9fO\x8130\x87\xfe\xe3iU\x15\x15mTPCEq\x0eL\x1b5\x9c\x91N\xa7Y^^\xa2\x99\xe5\x00\xc3\x01\xfa\xbb\x82\xaa\xa0*\xd8:\x0b\x06\xa5\x8f\xa5\xe6\xd8b\x01y;I}\xfe\x0b\xde\xdev\x8el=\x01\x9c\xc1\xafG\x11\x22\xc2\xc0\x83\x855\xefH_[\xd3\x06s\x85q\x96\xcao8|\xbe\x9f-]ij\x1f\xa6\x08^>\xe3\xe9\xc9\x96\xbco\xa2\xa8*\xc3\x17\xf6\xc5\xd1\x8d\x8e\xeb5\xfdx\x98L\xee\x12\xc9\xcf\xcf\xe1\xc5m\xb6\xed\xdcEW*E\xf1\x93\x0d\xfa\xaa\x8a\xaa\x01\xdah\x18\xab\xbb\xfb\x10\x95J\x05p\xfc\xac\xcc\x90l\xef\x82\xd3W\xd6\xa0\xfe\xd0~<u\x9d~yz\xf6\xd1\xad\x89\xa8WEPQD\x04UE\xa2(^\xdb\x8c\xde\xe4n\xc2\xf7O\x08\x0a\xfd\xfc\xa8\xcd\x13\x02+\xdf<\xc4\xa3\xe26\xf2\x1b_\xe5:\x86Z\xb7\x07\xd7\x0f\xec\xa9\xfb~b\x8e\x95\xafuf\x16<\x89\xbe\xdb\xcd\x0d\x01\x00^\xe7\x0e^[]\xac\x5c\xf4\xc4\xa5\xc4\xb3\xb2\xc1\xf8\xa9\xa9\xfa\x9d_.\xcc\x16\x0d_\xcbF\xcf\x00\x00\x00%tEXtcreate-date\x002009-11-16T22:18:16-07:00\xfdw\xf5u\x00\x00\x00%tEXtdate:create\x002010-01-11T06:52:57-07:00\x97\xdb\xcd\xa9\x00\x00\x00%tEXtdate:modify\x002010-01-11T06:52:57-07:00\xe6\x86u\x15\x00\x00\x00btEXtLicense\x00http://creativecommons.org/licenses/by/3.0/ or http://creativecommons.org/licenses/by/2.5/\x8b\x86<e\x00\x00\x00%tEXtmodify-date\x002006-03-12T21:48:22-07:00\x0d\xe3\x09M\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00\x1btEXtSource\x00FAMFAMFAM Silk Icons\x82zd\xfb\x00\x00\x003tEXtSource_URL\x00http://www.famfamfam.com/lab/icons/silk/\xc2\xc4\x0d\x0d\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x04~\x00\x00\x01\x00\x01\x00\x10\x10\x00\x00\x00\x00\x00\x00h\x04\x00\x00\x16\x00\x00\x00(\x00\x00\x00\x10\x00\x00\x00 \x00\x00\x00\x01\x00 \x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x1dW\xc4x\x03E\xb9\xdf\x04B\xbc\xfe\x03E\xb9\xe3\x03E\xb8z\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x1aW\xc3\x80%d\xc9\xfb!w\xe6\xff\x05y\xea\xff\x01d\xdd\xff\x04M\xbd\xfc\x03E\xb8z\xa9qQ\xa9\xc3\x8eh\xff\xc0\x8bf\xff\xbe\x88d\xff\xbb\x85a\xff\xb9\x83_\xff\xb4~\x5c\xff\xb2|Z\xff\xb1{X\xff\x16K\xae\xffc\x9d\xf4\xff\x18\x7f\xff\xff\x00v\xf8\xff\x00v\xee\xff\x03h\xe1\xff\x03E\xb9\xe4\xc8\x92l\xff\xe6\xe5\xe5\xff\xe5\xe5\xe5\xff\xe5\xe5\xe6\xff\xe5\xe5\xe5\xff\xe5\xe5\xe5\xff\xe6\xe5\xe5\xff\xe5\xe5\xe5\xff\xe6\xe5\xe5\xff\x05C\xbc\xff\xae\xcd\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x18\x7f\xef\xff\x04B\xbc\xfe\xca\x94n\xff\xe7\xe7\xe7\xff\xe8\xe7\xe7\xff\xe7\xe7\xe7\xff\xe7\xe7\xe7\xff\xe7\xe7\xe7\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff%]\xc2\xff\x8d\xb5\xf6\xffM\x92\xff\xff\x11w\xff\xff!\x86\xff\xff@\x8a\xeb\xff\x03D\xb9\xde\xcc\x97o\xff\xe9\xe9\xe9\xff\xd2\x83X\xff\xd2\x83X\xff\xd2\x83X\xff\xe9\xe9\xe9\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\x96\xb1\xe3\xff=v\xd2\xff\x8d\xb5\xf7\xff\xb8\xd6\xfe\xffr\xa8\xf5\xff.k\xca\xff\x04C\xbam\xd1\x9cs\xff\xec\xec\xec\xff\xec\xec\xeb\xff\xec\xec\xeb\xff\xec\xec\xec\xff\xec\xeb\xec\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xffu\x91\xc3\xff#[\xc0\xff\x05C\xbc\xff\x1dX\xbf\xff_a\x86\xff\xff\xff\xff\x00\xd4\x9eu\xff\xef\xee\xee\xff\xef\xef\xef\xff\xef\xee\xee\xff\xef\xee\xee\xff\xee\xef\xee\xff\xee\xee\xee\xff\xee\xef\xef\xff\xee\xee\xee\xff\xee\xee\xee\xff\xee\xee\xee\xff\xef\xee\xee\xff\xee\xee\xee\xff\xee\xee\xef\xff\xb2|Z\xff\xff\xff\xff\x00\xd5\xa0v\xff\xf1\xf1\xf0\xff\xf1\xf0\xf1\xff\xf0\xf1\xf1\xff\xf1\xf0\xf1\xff\xf1\xf1\xf1\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf1\xf1\xf1\xff\xb5~\x5c\xff\xff\xff\xff\x00\xd8\xa2y\xff\xf2\xf2\xf2\xff\xd2\x83X\xff\xd2\x83X\xff\xd2\x83X\xff\xf2\xf2\xf3\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf3\xf3\xf3\xff\xb7\x81^\xff\xff\xff\xff\x00\xd9\xa3y\xff\xf5\xf5\xf5\xff\xf5\xf5\xf4\xff\xf4\xf5\xf4\xff\xf4\xf4\xf4\xff\xf5\xf5\xf4\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xf4\xf4\xf5\xff\xba\x85`\xff\xff\xff\xff\x00\xdb\xa4z\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xbd\x87c\xff\xff\xff\xff\x00\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xc0\x8bf\xff\xff\xff\xff\x00\xdd\xac\x85\xfd\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xc1\x90o\xfd\xff\xff\xff\x00\xa9qQk\xdd\xb1\x8d\xf4\xdc\xa7{\xff\xdc\xa6z\xff\xda\xa4z\xff\xd8\xa2y\xff\xd5\xa0v\xff\xd4\x9eu\xff\xd2\x9ds\xff\xcf\x9ar\xff\xce\x99p\xff\xcb\x96o\xff\xc9\x94l\xff\xc4\x9az\xf4\xa9qQk\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xe3\x00\x00\xff\x81\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x80\x03\x00\x00\xff\xff\x00\x00\x00\x00\x04~\x00\x00\x01\x00\x01\x00\x10\x10\x00\x00\x00\x00\x00\x00h\x04\x00\x00\x16\x00\x00\x00(\x00\x00\x00\x10\x00\x00\x00 \x00\x00\x00\x01\x00 \x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x11=U\xf7(_\x87\xfbI\x88\xbd\xfbB\x8d\xbc\xc1-w\xb3\x22\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00+e\x83\xfb\x94\xc7\xf9\xff\x91\xc9\xf9\xffA\x85\xc9\xff\x1cd\xaa\xf3.y\xb9/\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xa9qQ\xa9\xc3\x8eh\xff\xc0\x8bf\xff\xbe\x88d\xffC\x89\xaa\xff\xe0\xf2\xff\xffT\x9a\xd8\xff\x1az\xbe\xffI\x98\xc5\xff@\x81\xb6\xff\x99yk\xff\xabuT\xff\xa9sS\xff\xa9qQ\xff\xa9qQ\xa9\xff\xff\xff\x00\xc8\x92l\xff\xe6\xe5\xe5\xff\xe5\xe5\xe5\xff\xe5\xe5\xe6\xff\x97\xb5\xc9\xffz\xb6\xd5\xff\x90\xb7\xd1\xffU\xc9\xe4\xff[\xdf\xf5\xffx\xd0\xed\xffO\x9b\xdb\xff\xcf\xd9\xe3\xff\xe5\xe6\xe6\xff\xe6\xe5\xe6\xff\xa9rQ\xff\xff\xff\xff\x00\xca\x94n\xff\xe7\xe7\xe7\xff\xe8\xe7\xe7\xff\xe7\xe7\xe7\xff\xe7\xe7\xe7\xff\xa4\xc6\xd7\xffu\xb8\xd6\xff\xc2\xf6\xfd\xffc\xdf\xf7\xff]\xe2\xf8\xffy\xd3\xf0\xffJ\x99\xdc\xff\xe6\xf1\xfa\xff\xe7\xe7\xe7\xff\xaasS\xff\xff\xff\xff\x00\xcc\x97o\xff\xe9\xe9\xe9\xff\xd2\x83X\xff\xd2\x83X\xff\xd2\x83X\xff\xe9\xe9\xe9\xff\x89\xae\xbf\xffw\xcb\xe7\xff\xc7\xf7\xfd\xff^\xdc\xf5\xffZ\xe1\xf7\xff{\xd4\xf1\xffL\x9a\xde\xff\xc4\xd7\xe7\xff\xacuT\xff\xff\xff\xff\x00\xd1\x9cs\xff\xec\xec\xec\xff\xec\xec\xeb\xff\xec\xec\xeb\xff\xec\xec\xec\xff\xec\xeb\xec\xff\xc3\xc3\xc3\xff\x95\xbd\xca\xffy\xd3\xee\xff\xc7\xf7\xfd\xff_\xdc\xf5\xff[\xe2\xf7\xffz\xd6\xf2\xffP\xa0\xe0\xff\x9c~n\xff\xff\xff\xff\x00\xd4\x9eu\xff\xef\xee\xee\xff\xef\xef\xef\xff\xef\xee\xee\xff\xef\xee\xee\xff\xee\xef\xee\xff\xee\xee\xee\xff\xee\xef\xef\xff\xb5\xde\xeb\xff}\xd4\xee\xff\xc4\xf6\xfd\xffl\xdd\xf6\xffm\xca\xed\xffc\xa3\xd7\xffc\x99\xc9\xffQ\x92\xca&\xd5\xa0v\xff\xf1\xf1\xf0\xff\xf1\xf0\xf1\xff\xf0\xf1\xf1\xff\xf1\xf0\xf1\xff\xf1\xf1\xf1\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb5\xe6\xf5\xff\x81\xd6\xee\xff\xb2\xe3\xf9\xff\x8b\xc0\xe7\xff\xae\xd3\xf6\xff\xc4\xe0\xfc\xfff\x9f\xd3\xf7\xd8\xa2y\xff\xf2\xf2\xf2\xff\xd2\x83X\xff\xd2\x83X\xff\xd2\x83X\xff\xf2\xf2\xf3\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb1\xe6\xf5\xffw\xbe\xe7\xff\xb4\xd2\xf0\xff\xe5\xf3\xff\xff\xac\xd2\xef\xffH\x8c\xc7\xe8\xd9\xa3y\xff\xf5\xf5\xf5\xff\xf5\xf5\xf4\xff\xf4\xf5\xf4\xff\xf4\xf4\xf4\xff\xf5\xf5\xf4\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\x94\xbd\xcc\xffX\xa5\xd8\xff\x85\xb1\xdb\xffF\x9d\xd0\xff+\x95\xd1^\xdb\xa4z\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xbd\x87c\xff\xff\xff\xff\x00\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xc0\x8bf\xff\xff\xff\xff\x00\xdd\xac\x85\xfd\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xc1\x90o\xfd\xff\xff\xff\x00\xa9qQk\xdd\xb1\x8d\xf4\xdc\xa7{\xff\xdc\xa6z\xff\xda\xa4z\xff\xd8\xa2y\xff\xd5\xa0v\xff\xd4\x9eu\xff\xd2\x9ds\xff\xcf\x9ar\xff\xce\x99p\xff\xcb\x96o\xff\xc9\x94l\xff\xc4\x9az\xf4\xa9qQk\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xf0\xff\x00\x00\xf0\x7f\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x80\x03\x00\x00\xff\xff\x00\x00\x00\x00\x04;\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04gAMA\x00\x00\xaf\xc87\x05\x8a\xe9\x00\x00\x00\x06bKGD\x00\x00\x00\x00\x00\x00\xf9C\xbb\x7f\x00\x00\x00\x09pHYs\x00\x00\x00H\x00\x00\x00H\x00F\xc9k>\x00\x00\x00\x09vpAg\x00\x00\x00\x10\x00\x00\x00\x10\x00\x5c\xc6\xad\xc3\x00\x00\x01\xf9IDAT8\xcb\xa5\x93MH\x94a\x14\x85\x9fw\x1ak\xc0~\xa0\x85\x96\x09\x95\x22\x14\x9211\x8b\xc1\x86\x88\xc2hSQ\x0b\xf7A\xb8H\x07\x09\x17\x09\xb5\xab\x85A?(\x19d\x8b\xa0\x9d\x05\x15\xd1*\x846\x22.b$\xc9F(P!\xbfI\x17\xe3X\xe3(~\xde{[|\x938P\xe4\xd0]\x9f\xfb\x9c{\xce\xcb\xeb\xcc\x8c\xff\x19w\xf1\xda`{\xe2d\xecN\xb6`\x95f\x80*\xa6\x8a\xa8`j\xa8)&\x82\x9aa\x22\x88*;\xb7\xfaK\xe9\xf4\xec\xf5\x97\xf7[\xfb\xc3\xb1\xe3\xb1\xbe\x8aHe\xa8:R\x96q\xe5RA\xfa\x80\xfep\xc1\xb7P!\x9b/\xfb\xf4e\xdfB\x00a\x13\xe3\xe6\xa5}e\x03\x92\xbd3\x04\x00S\xcc\x8c\xa0J\x03\x03\x9cc,\x95\xfa\xeb\xf2\xb1h\x14Q\x09\x00\x98!\x22\xb4\xf5N\xaf\x0b\x9et\x1e\x00 \x91H\xfc\x11\x90\xcf\xe7\xd1\xb5\x22@4h\xf8qr?8\x03s\xe8?\x9eVUQ\xd1b\x045T\x14\xe7\xc0\xb4\x18\xc3\x19\x8d\x8d\x8d\xe4r\x0b\x94\xb2\x1c`8@\x7fGP\x15T\x05\xdb \xc1 =\x99.qM\xcf}`r>E~\xe5\x07\xab\xfe*\xcbr\x088Gx\xcd\xf7\x11\x11:\x07\xe6\xd6\xc5\xbdm\xd5%\x1d\xbc\x1d\x1d$c\xe3\x9c:\x11\xa7vw\x03\xef'^3\xfai\x88xG\xcd\xdd\xb0\x89\xa2\xaa<\xb8R\x15X\x173n\x9cW\xc3\xcf\xb8p\xf6\x0c\x12\x12\x8e\xeema\xe8\xf3\x0b\xe2G\x9a\x99\xfe\xfa\xa6=\xa4\xaa\xa8Z\x10C\x03\x98\xaaRWW\x8f\xe7yx^\x86\xf9\x5c\x86\x0a\xb7\x9d\xf3\x87\x93\x00t\x9d\x1e\xa0\xbe\xaa\x09 \x12\x9e\x9d\x9ay~k\xd0oU\x11T\x14\x11AU\x11\xdf\x0f`fd\x17\x17\x98\xf0F\xf8\xe8\x0d\xd3\xdd\xf2\x94\x9ew\x97\x89l\xd9\x06\xb0\xe26\xf3\x1b\xe3\x1d5\xb7k\x0f\xee\xba\xd1\xdc\x94\xa0aO\x94/\xdf\xc7\x18\x19\x1f\xe6\xdb\xd4\xe2\xbdM\x01\x8a\x90\x1e\xe0*\xb0\x03\xf8\x09<\x1a}\xe8u\xff\x02\x22\xdb!\x1a\xd8EJ\xa5\x00\x00\x00%tEXtcreate-date\x002009-11-16T22:18:16-07:00\xfdw\xf5u\x00\x00\x00%tEXtdate:create\x002010-01-11T06:52:59-07:00\xc7\xe4\xb6\xf4\x00\x00\x00%tEXtdate:modify\x002010-01-11T06:52:59-07:00\xb6\xb9\x0eH\x00\x00\x00btEXtLicense\x00http://creativecommons.org/licenses/by/3.0/ or http://creativecommons.org/licenses/by/2.5/\x8b\x86<e\x00\x00\x00%tEXtmodify-date\x002006-03-12T21:48:22-07:00\x0d\xe3\x09M\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00\x1btEXtSource\x00FAMFAMFAM Silk Icons\x82zd\xfb\x00\x00\x003tEXtSource_URL\x00http://www.famfamfam.com/lab/icons/silk/\xc2\xc4\x0d\x0d\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x04~\x00\x00\x01\x00\x01\x00\x10\x10\x00\x00\x00\x00\x00\x00h\x04\x00\x00\x16\x00\x00\x00(\x00\x00\x00\x10\x00\x00\x00 \x00\x00\x00\x01\x00 \x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x19k7\x88\x19k7\xf2\x19k7\xff\x19k7\xf2\x19k7\x88\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\x19k7\x84(\x8cS\xffd\xba\x8d\xff\x95\xd2\xb2\xffd\xba\x8d\xff(\x8cS\xff\x19k7\x8c\xa9qQ\xa9\xc3\x8eh\xff\xc0\x8bf\xff\xbe\x88d\xff\xbb\x85a\xff\xb9\x83_\xff\xb4~\x5c\xff\xb2|Z\xff\xb1{X\xff l:\xffb\xba\x8b\xff`\xba\x87\xff\xff\xff\xff\xff`\xb9\x87\xffg\xbc\x8f\xff\x19k7\xf7\xc8\x92l\xff\xe6\xe5\xe5\xff\xe5\xe5\xe5\xff\xe5\xe5\xe6\xff\xe5\xe5\xe5\xff\xe5\xe5\xe5\xff\xe6\xe5\xe5\xff\xe5\xe5\xe5\xff\xe6\xe5\xe5\xff1{L\xff\x9c\xd4\xb6\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x95\xd2\xb2\xff\x19k7\xff\xca\x94n\xff\xe7\xe7\xe7\xff\xe8\xe7\xe7\xff\xe7\xe7\xe7\xff\xe7\xe7\xe7\xff\xe7\xe7\xe7\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xffJ\x8bb\xff\x90\xd3\xb1\xff\x92\xd6\xb1\xff\xff\xff\xff\xffe\xbc\x8c\xffg\xbc\x8f\xff\x19k7\xf7\xcc\x97o\xff\xe9\xe9\xe9\xff\xd2\x83X\xff\xd2\x83X\xff\xd2\x83X\xff\xe9\xe9\xe9\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa8\xc7\xb3\xffa\xab\x81\xff\x95\xd4\xb4\xff\xba\xe6\xd0\xffj\xbb\x8f\xff-\x8fW\xff\x19k7\x8c\xd1\x9cs\xff\xec\xec\xec\xff\xec\xec\xeb\xff\xec\xec\xeb\xff\xec\xec\xec\xff\xec\xeb\xec\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\x8f\xac\x9a\xff]\x96r\xffO\x8ef\xffI\x89`\xffqyQ\xff\xff\xff\xff\x00\xd4\x9eu\xff\xef\xee\xee\xff\xef\xef\xef\xff\xef\xee\xee\xff\xef\xee\xee\xff\xee\xef\xee\xff\xee\xee\xee\xff\xee\xef\xef\xff\xee\xee\xee\xff\xee\xee\xee\xff\xee\xee\xee\xff\xef\xee\xee\xff\xee\xee\xee\xff\xee\xee\xef\xff\xb2|Z\xff\xff\xff\xff\x00\xd5\xa0v\xff\xf1\xf1\xf0\xff\xf1\xf0\xf1\xff\xf0\xf1\xf1\xff\xf1\xf0\xf1\xff\xf1\xf1\xf1\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf1\xf1\xf1\xff\xb5~\x5c\xff\xff\xff\xff\x00\xd8\xa2y\xff\xf2\xf2\xf2\xff\xd2\x83X\xff\xd2\x83X\xff\xd2\x83X\xff\xf2\xf2\xf3\xff\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf3\xf3\xf3\xff\xb7\x81^\xff\xff\xff\xff\x00\xd9\xa3y\xff\xf5\xf5\xf5\xff\xf5\xf5\xf4\xff\xf4\xf5\xf4\xff\xf4\xf4\xf4\xff\xf5\xf5\xf4\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xc3\xc3\xc3\xff\xf4\xf4\xf5\xff\xba\x85`\xff\xff\xff\xff\x00\xdb\xa4z\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xf6\xf6\xf6\xff\xbd\x87c\xff\xff\xff\xff\x00\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xdc\xa7{\xff\xc0\x8bf\xff\xff\xff\xff\x00\xdd\xac\x85\xfd\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xe8\xb9\x92\xff\xc1\x90o\xfd\xff\xff\xff\x00\xa9qQk\xdd\xb1\x8d\xf4\xdc\xa7{\xff\xdc\xa6z\xff\xda\xa4z\xff\xd8\xa2y\xff\xd5\xa0v\xff\xd4\x9eu\xff\xd2\x9ds\xff\xcf\x9ar\xff\xce\x99p\xff\xcb\x96o\xff\xc9\x94l\xff\xc4\x9az\xf4\xa9qQk\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xff\xff\x00\xff\xc1\x00\x00\xff\x80\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x80\x03\x00\x00\xff\xff\x00\x00\x00\x00\x04\xac\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04gAMA\x00\x00\xaf\xc87\x05\x8a\xe9\x00\x00\x00\x06bKGD\x00\x00\x00\x00\x00\x00\xf9C\xbb\x7f\x00\x00\x00\x09pHYs\x00\x00\x00H\x00\x00\x00H\x00F\xc9k>\x00\x00\x00\x09vpAg\x00\x00\x00\x10\x00\x00\x00\x10\x00\x5c\xc6\xad\xc3\x00\x00\x02jIDAT8\xcb\xa5\x93MH\xd4Q\x14\xc5\x7fo\xfc\xcf\xe4\xc7\xd8\x90\x91\x06\xa1\xa6\x15\x11\x16QX\x10N\xe1\xaa \x0a*H\x0a\x22(B\x88\xb0\x08\xa2Z\xb4\xeb\x83jQXTT\xb6\x8c4BB\xa8E\xb5\x89d\x0a\x02u\x0c\xd3\xec\xc3D\xc6\x8f\xd2q\x14\xfd;:\xf3\xeem1\xe6\xc2j!\xbd\xd5\xe5q\xefy\xe7\x9e\xf3\x8eQU\xfe\xe7\x98\xdd'\xeb\x8e\x05\xcbK\xafD]\xcdR\x05DP\x11\xacXT\x14QA\xadETQk\xb1\x22\xcc\xf7%\xc6\xdb\xdb#g\xea\xafU\xdcrJ\xcbJox\xd3\xb3<y\xe9sz8k\xdc\xb57\x80[\x8e\x9bP\x8f\x1b\x1d\x9b3\xf5\x89\x84z\x00\x1c\xb5\xca\xb9=K\xe6\x0cPU\xddM\x0a@\x05U%%\xa5\x82\x02\xc6\xd0\xdc\xd4\xf4\xc7P\xc6T\x18\x7f\x7f#i\xfe5T\xe5\xbe\xa6\xf5\xf6\xf1\x83\x0e\xaaXk\xa9\xac\xfe>\xd3x\xff\xc4R\x00\x82\xc1\xe0\xcc\x9d\xdb\xd7\xc0hG\x0f\x19k\x0e\x10(ZG\xack%\x1d/j\xae:VR\x0a\xdf\xad*\x04\xa3\xa0\x06\x99e\xad\xdb\xf7\x9c\xc9X\x0b9+\xca\x88~m\xc7g\xa6\xc8\x9e\xbf\x18\xff\xc2\x82\x80\xa3\xa2\x88\x15\x8c\x01\x95\xe95\x8cRRRB,6Lr\xf8-i\xee;\x02\xc5\xdb\x98\xec\xab\xc5\x97i\xe8n\xe9`\xd4\x053\x19]\xeb\x11\xb1\x88X\x92\xd6b\xa7kI\x0ammm|nzD\xdax#\x81e\xdb\x89\xf7\xde\xc7x\x87\xf1\xfa\xb3\xc9\xb0C<\x8clbCU}\xa7\x93L$\xb0\xd6r\xe2\xde\xc0\x0c\xe5\xea\xca<\x92?C,\xcf\x8f\x12X\xbe\x8bx\xe4\x0e\x1eo\x92\xa9\xd1\x22\x86Ba26\x9f\xa5\xb7\xad\x7f\xda\x05+\x88\x08\xd7\x8f\xe4\xa6\xe8\x03\xd1\xaf/\xc9\xcb\x1c$\xb7d'S\xfd5\xa4\xf9\x94\xf8H!\x83\xa1f\x0a\xf6\xd50\xe4\x1aTzS\x00\x22\x82\x88\x02\x82\x01zZ\x1a\xf0\x9b\x1e\x92f\x09}\x1fn\xb2 \xd7G<\x9aO\xf4\xfdG\xd2\xcb/28\x9e\xb2\xfa\xb7\xd0N\xa4\xab\xfb\xf1\xf9\xbaD\x85X\x8bXa\xaby\xc2\xde\xa3\x0f\xf8T{\x8a\xce7!\xe6\x15\xaced \xc2\xb3\xf8~\x06:\xbf\xa0\xd2\x89\x08\x00\x8f\x01\xcc\xec4^\xa8\x5c\x9d8}\xf8\xa8\x83\xc7\xd2\xf2\xea)\xdd]\x9f\xc7\x02\x8br\x82[/\x85\xc3\x7fM\xe3l\x80\x8a-9\x13\xeb\x8b\xf3\x9c\x8d\xab\x8aP\xefdh\xe2\xc7\xcfC;.\xb7~\xfb\xd7\x97\xfe\x05\xfaDDS\xe7JD\xbf\x00\x00\x00%tEXtcreate-date\x002009-11-16T22:18:16-07:00\xfdw\xf5u\x00\x00\x00%tEXtdate:create\x002010-01-11T06:52:45-07:00\xcc\xee\xdc\x1e\x00\x00\x00%tEXtdate:modify\x002010-01-11T06:52:45-07:00\xbd\xb3d\xa2\x00\x00\x00btEXtLicense\x00http://creativecommons.org/licenses/by/3.0/ or http://creativecommons.org/licenses/by/2.5/\x8b\x86<e\x00\x00\x00%tEXtmodify-date\x002006-03-12T21:48:22-07:00\x0d\xe3\x09M\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00\x1btEXtSource\x00FAMFAMFAM Silk Icons\x82zd\xfb\x00\x00\x003tEXtSource_URL\x00http://www.famfamfam.com/lab/icons/silk/\xc2\xc4\x0d\x0d\x00\x00\x00\x00IEND\xaeB`\x82"
qt_resource_name = "\x00\x09\x08)\x1d\x09\x00q\x00t\x00a\x00l\x00c\x00h\x00e\x00m\x00y\x00\x12\x00\xf0,'\x00d\x00e\x00f\x00a\x00u\x00l\x00t\x00-\x00d\x00e\x00l\x00e\x00t\x00e\x00.\x00p\x00n\x00g\x00\x12\x00\xf04\xff\x00d\x00e\x00f\x00a\x00u\x00l\x00t\x00-\x00d\x00e\x00l\x00e\x00t\x00e\x00.\x00i\x00c\x00o\x00\x10\x0a\x9b\x07\xdf\x00d\x00e\x00f\x00a\x00u\x00l\x00t\x00-\x00e\x00d\x00i\x00t\x00.\x00i\x00c\x00o\x00\x0f\x0d\xd3\x93\xa7\x00d\x00e\x00f\x00a\x00u\x00l\x00t\x00-\x00n\x00e\x00w\x00.\x00p\x00n\x00g\x00\x0f\x0d\xd3\x8b\x7f\x00d\x00e\x00f\x00a\x00u\x00l\x00t\x00-\x00n\x00e\x00w\x00.\x00i\x00c\x00o\x00\x10\x0a\x9b\x1f\x07\x00d\x00e\x00f\x00a\x00u\x00l\x00t\x00-\x00e\x00d\x00i\x00t\x00.\x00p\x00n\x00g"
qt_resource_struct = "\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\x00\x02\x00\x00\x00\x06\x00\x00\x00\x02\x00\x00\x00\x18\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00B\x00\x00\x00\x00\x00\x01\x00\x00\x04;\x00\x00\x00l\x00\x00\x00\x00\x00\x01\x00\x00\x08\xbd\x00\x00\x00\xda\x00\x00\x00\x00\x00\x01\x00\x00\x16\x00\x00\x00\x00\xb6\x00\x00\x00\x00\x00\x01\x00\x00\x11~\x00\x00\x00\x92\x00\x00\x00\x00\x00\x01\x00\x00\x0d?"
def qInitResources():
    QtCore.qRegisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
